powered by
Quickly get a grasp of how much a search term or a combination of search terms are searched for on google.
Inspired by this discussion on Stackoverflow: https://stackoverflow.com/questions/30199157/r-google-search-result-count-retrieve
google.hits(search.terms)
Search terms encapsulated in "".
# NOT RUN { google.hits("my search terms") # Your Search URL: # https://www.google.com/search?q=my%20search%20terms # No. of Hits: # [1] 117000000 # }
Run the code above in your browser using DataLab